Class: BrazeClient::Attributes

Inherits:
Object
  • Object
show all
Defined in:
lib/braze_api_client/models/attributes.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Attributes

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/braze_api_client/models/attributes.rb', line 149

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `BrazeClient::Attributes` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `BrazeClient::Attributes`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'current_location')
    self.current_location = attributes[:'current_location']
  end

  if attributes.key?(:'date_of_first_session')
    self.date_of_first_session = attributes[:'date_of_first_session']
  end

  if attributes.key?(:'date_of_last_session')
    self.date_of_last_session = attributes[:'date_of_last_session']
  end

  if attributes.key?(:'dob')
    self.dob = attributes[:'dob']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'email_subscribe')
    self.email_subscribe = attributes[:'email_subscribe']
  end

  if attributes.key?(:'email_open_tracking_disabled')
    self.email_open_tracking_disabled = attributes[:'email_open_tracking_disabled']
  end

  if attributes.key?(:'email_click_tracking_disabled')
    self.email_click_tracking_disabled = attributes[:'email_click_tracking_disabled']
  end

  if attributes.key?(:'facebook')
    self.facebook = attributes[:'facebook']
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'gender')
    self.gender = attributes[:'gender']
  end

  if attributes.key?(:'home_city')
    self.home_city = attributes[:'home_city']
  end

  if attributes.key?(:'language')
    self.language = attributes[:'language']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'marked_email_as_spam_at')
    self.marked_email_as_spam_at = attributes[:'marked_email_as_spam_at']
  end

  if attributes.key?(:'phone')
    self.phone = attributes[:'phone']
  end

  if attributes.key?(:'push_subscribe')
    self.push_subscribe = attributes[:'push_subscribe']
  end

  if attributes.key?(:'push_tokens')
    if (value = attributes[:'push_tokens']).is_a?(Array)
      self.push_tokens = value
    end
  end

  if attributes.key?(:'time_zone')
    self.time_zone = attributes[:'time_zone']
  end

  if attributes.key?(:'twitter')
    self.twitter = attributes[:'twitter']
  end
end

Instance Attribute Details

#countryObject

Returns the value of attribute country.



18
19
20
# File 'lib/braze_api_client/models/attributes.rb', line 18

def country
  @country
end

#current_locationObject

Returns the value of attribute current_location.



20
21
22
# File 'lib/braze_api_client/models/attributes.rb', line 20

def current_location
  @current_location
end

#date_of_first_sessionObject

Returns the value of attribute date_of_first_session.



22
23
24
# File 'lib/braze_api_client/models/attributes.rb', line 22

def date_of_first_session
  @date_of_first_session
end

#date_of_last_sessionObject

Returns the value of attribute date_of_last_session.



24
25
26
# File 'lib/braze_api_client/models/attributes.rb', line 24

def date_of_last_session
  @date_of_last_session
end

#dobObject

Returns the value of attribute dob.



26
27
28
# File 'lib/braze_api_client/models/attributes.rb', line 26

def dob
  @dob
end

#emailObject

Returns the value of attribute email.



28
29
30
# File 'lib/braze_api_client/models/attributes.rb', line 28

def email
  @email
end

#email_click_tracking_disabledObject

Returns the value of attribute email_click_tracking_disabled.



34
35
36
# File 'lib/braze_api_client/models/attributes.rb', line 34

def email_click_tracking_disabled
  @email_click_tracking_disabled
end

#email_open_tracking_disabledObject

Returns the value of attribute email_open_tracking_disabled.



32
33
34
# File 'lib/braze_api_client/models/attributes.rb', line 32

def email_open_tracking_disabled
  @email_open_tracking_disabled
end

#email_subscribeObject

Returns the value of attribute email_subscribe.



30
31
32
# File 'lib/braze_api_client/models/attributes.rb', line 30

def email_subscribe
  @email_subscribe
end

#facebookObject

Returns the value of attribute facebook.



36
37
38
# File 'lib/braze_api_client/models/attributes.rb', line 36

def facebook
  @facebook
end

#first_nameObject

Returns the value of attribute first_name.



38
39
40
# File 'lib/braze_api_client/models/attributes.rb', line 38

def first_name
  @first_name
end

#genderObject

Returns the value of attribute gender.



40
41
42
# File 'lib/braze_api_client/models/attributes.rb', line 40

def gender
  @gender
end

#home_cityObject

Returns the value of attribute home_city.



42
43
44
# File 'lib/braze_api_client/models/attributes.rb', line 42

def home_city
  @home_city
end

#languageObject

Returns the value of attribute language.



44
45
46
# File 'lib/braze_api_client/models/attributes.rb', line 44

def language
  @language
end

#last_nameObject

Returns the value of attribute last_name.



46
47
48
# File 'lib/braze_api_client/models/attributes.rb', line 46

def last_name
  @last_name
end

#marked_email_as_spam_atObject

Returns the value of attribute marked_email_as_spam_at.



48
49
50
# File 'lib/braze_api_client/models/attributes.rb', line 48

def marked_email_as_spam_at
  @marked_email_as_spam_at
end

#phoneObject

Returns the value of attribute phone.



50
51
52
# File 'lib/braze_api_client/models/attributes.rb', line 50

def phone
  @phone
end

#push_subscribeObject

Returns the value of attribute push_subscribe.



52
53
54
# File 'lib/braze_api_client/models/attributes.rb', line 52

def push_subscribe
  @push_subscribe
end

#push_tokensObject

Returns the value of attribute push_tokens.



54
55
56
# File 'lib/braze_api_client/models/attributes.rb', line 54

def push_tokens
  @push_tokens
end

#time_zoneObject

Returns the value of attribute time_zone.



56
57
58
# File 'lib/braze_api_client/models/attributes.rb', line 56

def time_zone
  @time_zone
end

#twitterObject

Returns the value of attribute twitter.



58
59
60
# File 'lib/braze_api_client/models/attributes.rb', line 58

def twitter
  @twitter
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



110
111
112
# File 'lib/braze_api_client/models/attributes.rb', line 110

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/braze_api_client/models/attributes.rb', line 83

def self.attribute_map
  {
    :'country' => :'country',
    :'current_location' => :'current_location',
    :'date_of_first_session' => :'date_of_first_session',
    :'date_of_last_session' => :'date_of_last_session',
    :'dob' => :'dob',
    :'email' => :'email',
    :'email_subscribe' => :'email_subscribe',
    :'email_open_tracking_disabled' => :'email_open_tracking_disabled',
    :'email_click_tracking_disabled' => :'email_click_tracking_disabled',
    :'facebook' => :'facebook',
    :'first_name' => :'first_name',
    :'gender' => :'gender',
    :'home_city' => :'home_city',
    :'language' => :'language',
    :'last_name' => :'last_name',
    :'marked_email_as_spam_at' => :'marked_email_as_spam_at',
    :'phone' => :'phone',
    :'push_subscribe' => :'push_subscribe',
    :'push_tokens' => :'push_tokens',
    :'time_zone' => :'time_zone',
    :'twitter' => :'twitter'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



341
342
343
# File 'lib/braze_api_client/models/attributes.rb', line 341

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



142
143
144
145
# File 'lib/braze_api_client/models/attributes.rb', line 142

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/braze_api_client/models/attributes.rb', line 115

def self.openapi_types
  {
    :'country' => :'String',
    :'current_location' => :'AttributesCurrentLocation',
    :'date_of_first_session' => :'Time',
    :'date_of_last_session' => :'Time',
    :'dob' => :'Date',
    :'email' => :'String',
    :'email_subscribe' => :'String',
    :'email_open_tracking_disabled' => :'Boolean',
    :'email_click_tracking_disabled' => :'Boolean',
    :'facebook' => :'AttributesFacebook',
    :'first_name' => :'String',
    :'gender' => :'String',
    :'home_city' => :'String',
    :'language' => :'String',
    :'last_name' => :'String',
    :'marked_email_as_spam_at' => :'Time',
    :'phone' => :'String',
    :'push_subscribe' => :'String',
    :'push_tokens' => :'Array<AttributesPushTokens>',
    :'time_zone' => :'String',
    :'twitter' => :'AttributesTwitter'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/braze_api_client/models/attributes.rb', line 300

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      country == o.country &&
      current_location == o.current_location &&
      date_of_first_session == o.date_of_first_session &&
      date_of_last_session == o.date_of_last_session &&
      dob == o.dob &&
      email == o.email &&
      email_subscribe == o.email_subscribe &&
      email_open_tracking_disabled == o.email_open_tracking_disabled &&
      email_click_tracking_disabled == o.email_click_tracking_disabled &&
      facebook == o.facebook &&
      first_name == o.first_name &&
      gender == o.gender &&
      home_city == o.home_city &&
      language == o.language &&
      last_name == o.last_name &&
      marked_email_as_spam_at == o.marked_email_as_spam_at &&
      phone == o.phone &&
      push_subscribe == o.push_subscribe &&
      push_tokens == o.push_tokens &&
      time_zone == o.time_zone &&
      twitter == o.twitter
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/braze_api_client/models/attributes.rb', line 371

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = BrazeClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



442
443
444
445
446
447
448
449
450
451
452
453
454
# File 'lib/braze_api_client/models/attributes.rb', line 442

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/braze_api_client/models/attributes.rb', line 348

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


328
329
330
# File 'lib/braze_api_client/models/attributes.rb', line 328

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



334
335
336
# File 'lib/braze_api_client/models/attributes.rb', line 334

def hash
  [country, current_location, date_of_first_session, date_of_last_session, dob, email, email_subscribe, email_open_tracking_disabled, email_click_tracking_disabled, facebook, first_name, gender, home_city, language, last_name, marked_email_as_spam_at, phone, push_subscribe, push_tokens, time_zone, twitter].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



251
252
253
254
# File 'lib/braze_api_client/models/attributes.rb', line 251

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



418
419
420
# File 'lib/braze_api_client/models/attributes.rb', line 418

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/braze_api_client/models/attributes.rb', line 424

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



412
413
414
# File 'lib/braze_api_client/models/attributes.rb', line 412

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



258
259
260
261
262
263
264
265
266
# File 'lib/braze_api_client/models/attributes.rb', line 258

def valid?
  email_subscribe_validator = EnumAttributeValidator.new('String', ["opted_in", "unsubscribed", "subscribed"])
  return false unless email_subscribe_validator.valid?(@email_subscribe)
  gender_validator = EnumAttributeValidator.new('String', ["M", "F", "O", "N", "P", "null"])
  return false unless gender_validator.valid?(@gender)
  push_subscribe_validator = EnumAttributeValidator.new('String', ["opted_in", "unsubscribed", "subscribed"])
  return false unless push_subscribe_validator.valid?(@push_subscribe)
  true
end